@@ -1,16 +1,20 @@
 from dataclasses import dataclass
-from typing import Any, Dict, Type, Union
+from typing import Dict, Union
 
 import docstring_parser
-from strong_typing import (
-    JsonSchemaGenerator,
-    Schema,
-    SchemaOptions,
+from strong_typing.inspection import (
     is_generic_list,
     is_type_optional,
     unwrap_generic_list,
     unwrap_optional_type,
 )
+from strong_typing.name import python_type_to_name
+from strong_typing.schema import (
+    JsonSchemaGenerator,
+    Schema,
+    SchemaOptions,
+    get_schema_identifier,
+)
 
 from .operations import HTTPMethod, get_endpoint_events, get_endpoint_operations
 from .options import *
@@ -32,18 +36,18 @@ from .specification import (
 
 
 class Generator:
-    endpoint: Type
+    endpoint: type
     schema_generator: JsonSchemaGenerator
     schemas: Dict[str, Schema]
 
-    def __init__(self, endpoint: Type):
+    def __init__(self, endpoint: type):
         self.endpoint = endpoint
         self.schema_generator = JsonSchemaGenerator(
             SchemaOptions(definitions_path="#/components/schemas/")
         )
         self.schemas = {}
 
-    def _classdef_to_schema(self, typ: Type) -> Schema:
+    def _classdef_to_schema(self, typ: type) -> Schema:
         """
         Converts a type to a JSON schema.
         For nested types found in the type hierarchy, adds the type to the schema registry in the OpenAPI specification section `components`.
@@ -58,22 +62,35 @@ class Generator:
 
         return type_schema
 
-    def _classdef_to_ref(self, typ: Type) -> Union[Schema, SchemaRef]:
+    def _classdef_to_ref(self, typ: type) -> Union[Schema, SchemaRef]:
         """
         Converts a type to a JSON schema, and if possible, returns a schema reference.
         For composite types (such as classes), adds the type to the schema registry in the OpenAPI specification section `components`.
         """
 
         type_schema = self._classdef_to_schema(typ)
-        type_name = getattr(typ, "__name__", None)
-        if typ is str or typ is int or typ is float or type_name is None:
+        if typ is str or typ is int or typ is float:
+            # represent simple types as themselves
             return type_schema
-        else:
-            if type_name not in self.schemas:
-                self.schemas[type_name] = type_schema
-            return SchemaRef(type_name)
 
-    def _build_content(self, payload_type: Type) -> Dict[str, MediaType]:
+        type_name = get_schema_identifier(typ)
+        if type_name is not None:
+            return self._build_ref(type_name, type_schema)
+
+        try:
+            type_name = python_type_to_name(typ)
+            return self._build_ref(type_name, type_schema)
+        except TypeError:
+            pass
+
+        return type_schema
+
+    def _build_ref(self, type_name: str, type_schema: Schema) -> SchemaRef:
+        if type_name not in self.schemas:
+            self.schemas[type_name] = type_schema
+        return SchemaRef(type_name)
+
+    def _build_content(self, payload_type: type) -> Dict[str, MediaType]:
         if is_generic_list(payload_type):
             media_type = "application/jsonl"
             item_type = unwrap_generic_list(payload_type)
@@ -83,7 +100,7 @@ class Generator:
 
         return {media_type: MediaType(schema=self._classdef_to_ref(item_type))}
 
-    def _build_response(self, response_type: Type, description: str) -> Response:
+    def _build_response(self, response_type: type, description: str) -> Response:
         if response_type is not None:
             return Response(
                 description=description, content=self._build_content(response_type)
@@ -202,6 +219,7 @@ class Generator:
                 requestBody=requestBody,
                 responses=responses,
                 callbacks=callbacks,
+                security=[] if op.public else None,
             )
 
             if op.http_method is HTTPMethod.GET:
@@ -215,7 +233,7 @@ class Generator:
             elif op.http_method is HTTPMethod.PATCH:
                 pathItem = PathItem(patch=operation)
             else:
-                raise NotImplementedError()
+                raise NotImplementedError(f"unknown HTTP method: {op.http_method}")
 
             route = op.get_route()
             if route in paths:
